# pulse-schemas

A Python package for managing user profile schemas using Pydantic.

## Features

- Shared library to store Pydantic models

## Installation

```
pip install pulse-schemas
```

## Usage

This project is a shared library that contains custom schemas for the pulse living project.

### Example Usage

```
from pulse_schemas.schema import ProfileSchema
```


